""" Init file for SRPTime

Context : SRP
Module  : SRPTime
Version : 1.0.o
Author  : Stefano Covino
Date    : 27/09/2012
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (27/09/2012) First named version.
"""



__all__ = ['UT2MJD',]


# Time constants
JD2MJD = 2400000.5