""" Init file for SRPNet

Context : SRP
Module  : Net
Version : 1.0.0
Author  : Stefano Covino
Date    : 14/11/2010
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino

Usage   : to be imported

History : (14/11/2010) First named version.
"""


__all__ = ['GetWebPage', 'SendEMail']



