""" Init file for SRPPolarimetry

Context : SRP
Module  : Polarimetry
Version : 1.0.0
Author  : Stefano Covino
Date    : 15/02/2012
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino

Usage   : to be imported

History : (15/02/2012) First named version.
"""


__all__ = ['Counts2Mag', 'Mag2Counts']



