""" Init file for SRPFrames

Context : SRP
Module  : Frames
Version : 1.0.1
Author  : Stefano Covino
Date    : 31/08/2012
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (31/08/2012) First named version.
"""



__all__ = ['AstrometryClass', 'EclipseConstants', 'EclipseObjectClass', 
           'getCenterRADEC', 'Pixel2WCS', 'SExtractorConstants', 'SourceObjectsClass', 
           'WCS2Pixel']


