""" Init file for SRPSystem

Context : SRP
Module  : System
Version : 1.0.5
Author  : Stefano Covino
Date    : 30/08/2013
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino

Usage   : to be imported

History : (24/08/2011) First named version.
        : (02/10/2011) List of Fits files function.
        : (05/02/2012) Solid path.
        : (15/06/2012) New function.
        : (29/08/2013) New function.
        : (30/08/2013) New function.
"""



__all__ = ['CopyGzipped', 'EnsureDir', 'HowOldIsFile', 'ListDirTimeSorted', 
            'ListOfFitsFiles', 'Pipe', 'SRPPath', 'Touch', 'Which']

