""" 

Context : SRP
Module  : Tables
Version : 1.0.1
Author  : Stefano Covino
Date    : 11/02/2013
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (08/11/2010) First version.
        : (11/02/2013) CleanStr and SkyStr added.
"""



__all__ = ['CleanStr', 'FindObjects', 'SkyStr']

